ProjectivePoint

Struct ProjectivePoint 

pub struct ProjectivePoint { /* private fields */ }
A point on the secp256k1 curve in projective coordinates.

Implementations

Source

impl ProjectivePoint

pub fn mul_by_generator(k: &Scalar) -> ProjectivePoint

Calculates k * G, where G is the generator.

pub fn mul_by_generator_vartime(k: &Scalar) -> ProjectivePoint

Calculates k * G in variable-time, where G is the generator.

Source

impl ProjectivePoint

pub const IDENTITY: Self

Additive identity of the group: the point at infinity.

pub const GENERATOR: Self

Base point of secp256k1.

pub fn to_affine(&self) -> AffinePoint

Returns the affine representation of this point.

pub fn double(&self) -> ProjectivePoint

Doubles this point.

pub fn double_in_place(&mut self)

Doubles this point in-place.

pub fn endomorphism(&self) -> Self

Calculates SECP256k1 endomorphism: self * lambda.

pub fn eq_affine(&self, other: &AffinePoint) -> Choice

Check whether self is equal to an affine point.

This is a lot faster than first converting self to an AffinePoint and then doing the comparison. It is a little bit faster than converting other to a ProjectivePoint first.