pub struct Scalar(/* private fields */);Expand description
Scalars are elements in the finite field modulo n.
Trait impls
Much of the important functionality of scalars is provided by traits from
the ff crate, which is re-exported as
k256::elliptic_curve::ff:
Field- represents elements of finite fields and provides:Field::random- generate a random scalardouble,square, andinvertoperations- Bounds for
Add,Sub,Mul, andNeg(as well as*Assignequivalents) - Bounds for
ConditionallySelectablefrom thesubtlecrate
PrimeField- represents elements of prime fields and provides:from_repr/to_reprfor converting field elements from/to big integers.multiplicative_generatorandroot_of_unityconstants.
Please see the documentation for the relevant traits for more information.
serde support
When the serde feature of this crate is enabled, the Serialize and
Deserialize traits are impl’d for this type.
The serialization is a fixed-width big endian encoding. When used with textual formats, the binary data is encoded as hexadecimal.
Implementations
Sourceimpl Scalar
impl Scalar
Sourcepub fn to_bytes(&self) -> FieldBytes
pub fn to_bytes(&self) -> FieldBytes
Returns the SEC1 encoding of this scalar.
Sourcepub fn shr_vartime(&self, shift: u32) -> Scalar
pub fn shr_vartime(&self, shift: u32) -> Scalar
Right shifts the scalar.
Note: not constant-time with respect to the shift parameter.
Sourcepub fn invert(&self) -> CtOption<Self>
pub fn invert(&self) -> CtOption<Self>
Returns the multiplicative inverse of self, if self is non-zero.
Sourcepub fn invert_vartime(&self) -> CtOption<Self>
pub fn invert_vartime(&self) -> CtOption<Self>
Returns the multiplicative inverse of self in variable-time, if self is non-zero.
Sourcepub fn generate_biased_from_rng<R: CryptoRng + ?Sized>(rng: &mut R) -> Self
pub fn generate_biased_from_rng<R: CryptoRng + ?Sized>(rng: &mut R) -> Self
Returns a (nearly) uniformly-random scalar, generated in constant time.
Sourcepub fn try_generate_biased_from_rng<R: TryCryptoRng + ?Sized>(
rng: &mut R,
) -> Result<Self, R::Error>
pub fn try_generate_biased_from_rng<R: TryCryptoRng + ?Sized>( rng: &mut R, ) -> Result<Self, R::Error>
Returns a (nearly) uniformly-random scalar, generated in constant time.
Errors
Propagates R::Error on RNG failure.