Secp256k1

Struct Secp256k1 

pub struct Secp256k1;
secp256k1 (K-256) elliptic curve.

Specified in Certicom’s SECG in “SEC 2: Recommended Elliptic Curve Domain Parameters”:

https://www.secg.org/sec2-v2.pdf

The curve’s equation is y² = x³ + 7 over a ~256-bit prime field.

It’s primarily notable for usage in Bitcoin and other cryptocurrencies, particularly in conjunction with the Elliptic Curve Digital Signature Algorithm (ECDSA).